# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTZuoraWorkflowChangePlanOnSubscription(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'old_subscription_id': 'str',
        'old_bt_billing_plan_id': 'str',
        'new_bt_billing_plan_id': 'str',
        'effective_date': 'str',
        'new_subscription_id': 'str'
    }

    attribute_map = {
        'old_subscription_id': 'oldSubscriptionId',
        'old_bt_billing_plan_id': 'oldBTBillingPlanId',
        'new_bt_billing_plan_id': 'newBTBillingPlanId',
        'effective_date': 'effectiveDate',
        'new_subscription_id': 'newSubscriptionId'
    }

    def __init__(self, old_subscription_id=None, old_bt_billing_plan_id=None, new_bt_billing_plan_id=None, effective_date=None, new_subscription_id=None):  # noqa: E501
        """BTZuoraWorkflowChangePlanOnSubscription - a model defined in OpenAPI"""  # noqa: E501

        self._old_subscription_id = None
        self._old_bt_billing_plan_id = None
        self._new_bt_billing_plan_id = None
        self._effective_date = None
        self._new_subscription_id = None
        self.discriminator = None

        if old_subscription_id is not None:
            self.old_subscription_id = old_subscription_id
        if old_bt_billing_plan_id is not None:
            self.old_bt_billing_plan_id = old_bt_billing_plan_id
        if new_bt_billing_plan_id is not None:
            self.new_bt_billing_plan_id = new_bt_billing_plan_id
        if effective_date is not None:
            self.effective_date = effective_date
        if new_subscription_id is not None:
            self.new_subscription_id = new_subscription_id

    @property
    def old_subscription_id(self):
        """Gets the old_subscription_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501


        :return: The old_subscription_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501
        :rtype: str
        """
        return self._old_subscription_id

    @old_subscription_id.setter
    def old_subscription_id(self, old_subscription_id):
        """Sets the old_subscription_id of this BTZuoraWorkflowChangePlanOnSubscription.


        :param old_subscription_id: The old_subscription_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501
        :type: str
        """

        self._old_subscription_id = old_subscription_id

    @property
    def old_bt_billing_plan_id(self):
        """Gets the old_bt_billing_plan_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501


        :return: The old_bt_billing_plan_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501
        :rtype: str
        """
        return self._old_bt_billing_plan_id

    @old_bt_billing_plan_id.setter
    def old_bt_billing_plan_id(self, old_bt_billing_plan_id):
        """Sets the old_bt_billing_plan_id of this BTZuoraWorkflowChangePlanOnSubscription.


        :param old_bt_billing_plan_id: The old_bt_billing_plan_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501
        :type: str
        """

        self._old_bt_billing_plan_id = old_bt_billing_plan_id

    @property
    def new_bt_billing_plan_id(self):
        """Gets the new_bt_billing_plan_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501


        :return: The new_bt_billing_plan_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501
        :rtype: str
        """
        return self._new_bt_billing_plan_id

    @new_bt_billing_plan_id.setter
    def new_bt_billing_plan_id(self, new_bt_billing_plan_id):
        """Sets the new_bt_billing_plan_id of this BTZuoraWorkflowChangePlanOnSubscription.


        :param new_bt_billing_plan_id: The new_bt_billing_plan_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501
        :type: str
        """

        self._new_bt_billing_plan_id = new_bt_billing_plan_id

    @property
    def effective_date(self):
        """Gets the effective_date of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501


        :return: The effective_date of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501
        :rtype: str
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """Sets the effective_date of this BTZuoraWorkflowChangePlanOnSubscription.


        :param effective_date: The effective_date of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501
        :type: str
        """

        self._effective_date = effective_date

    @property
    def new_subscription_id(self):
        """Gets the new_subscription_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501


        :return: The new_subscription_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501
        :rtype: str
        """
        return self._new_subscription_id

    @new_subscription_id.setter
    def new_subscription_id(self, new_subscription_id):
        """Sets the new_subscription_id of this BTZuoraWorkflowChangePlanOnSubscription.


        :param new_subscription_id: The new_subscription_id of this BTZuoraWorkflowChangePlanOnSubscription.  # noqa: E501
        :type: str
        """

        self._new_subscription_id = new_subscription_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTZuoraWorkflowChangePlanOnSubscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTUploadParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'element_id': 'str',
        'document_name': 'str',
        'cloud_storage_account_id': 'str',
        'state': 'str',
        'name': 'str'
    }

    attribute_map = {
        'element_id': 'elementId',
        'document_name': 'documentName',
        'cloud_storage_account_id': 'cloudStorageAccountId',
        'state': 'state',
        'name': 'name'
    }

    def __init__(self, element_id=None, document_name=None, cloud_storage_account_id=None, state=None, name=None):  # noqa: E501
        """BTUploadParams - a model defined in OpenAPI"""  # noqa: E501

        self._element_id = None
        self._document_name = None
        self._cloud_storage_account_id = None
        self._state = None
        self._name = None
        self.discriminator = None

        if element_id is not None:
            self.element_id = element_id
        if document_name is not None:
            self.document_name = document_name
        if cloud_storage_account_id is not None:
            self.cloud_storage_account_id = cloud_storage_account_id
        if state is not None:
            self.state = state
        if name is not None:
            self.name = name

    @property
    def element_id(self):
        """Gets the element_id of this BTUploadParams.  # noqa: E501


        :return: The element_id of this BTUploadParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTUploadParams.


        :param element_id: The element_id of this BTUploadParams.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def document_name(self):
        """Gets the document_name of this BTUploadParams.  # noqa: E501


        :return: The document_name of this BTUploadParams.  # noqa: E501
        :rtype: str
        """
        return self._document_name

    @document_name.setter
    def document_name(self, document_name):
        """Sets the document_name of this BTUploadParams.


        :param document_name: The document_name of this BTUploadParams.  # noqa: E501
        :type: str
        """

        self._document_name = document_name

    @property
    def cloud_storage_account_id(self):
        """Gets the cloud_storage_account_id of this BTUploadParams.  # noqa: E501


        :return: The cloud_storage_account_id of this BTUploadParams.  # noqa: E501
        :rtype: str
        """
        return self._cloud_storage_account_id

    @cloud_storage_account_id.setter
    def cloud_storage_account_id(self, cloud_storage_account_id):
        """Sets the cloud_storage_account_id of this BTUploadParams.


        :param cloud_storage_account_id: The cloud_storage_account_id of this BTUploadParams.  # noqa: E501
        :type: str
        """

        self._cloud_storage_account_id = cloud_storage_account_id

    @property
    def state(self):
        """Gets the state of this BTUploadParams.  # noqa: E501


        :return: The state of this BTUploadParams.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTUploadParams.


        :param state: The state of this BTUploadParams.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def name(self):
        """Gets the name of this BTUploadParams.  # noqa: E501


        :return: The name of this BTUploadParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTUploadParams.


        :param name: The name of this BTUploadParams.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTUploadParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMImport(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'imported_external_document_id': 'str',
        'element_import': 'bool',
        'namespace': 'str',
        'node_id': 'str',
        'import_microversion': 'str',
        'version': 'str',
        'path': 'str'
    }

    attribute_map = {
        'imported_external_document_id': 'importedExternalDocumentId',
        'element_import': 'elementImport',
        'namespace': 'namespace',
        'node_id': 'nodeId',
        'import_microversion': 'importMicroversion',
        'version': 'version',
        'path': 'path'
    }

    def __init__(self, imported_external_document_id=None, element_import=None, namespace=None, node_id=None, import_microversion=None, version=None, path=None):  # noqa: E501
        """BTMImport - a model defined in OpenAPI"""  # noqa: E501

        self._imported_external_document_id = None
        self._element_import = None
        self._namespace = None
        self._node_id = None
        self._import_microversion = None
        self._version = None
        self._path = None
        self.discriminator = None

        if imported_external_document_id is not None:
            self.imported_external_document_id = imported_external_document_id
        if element_import is not None:
            self.element_import = element_import
        if namespace is not None:
            self.namespace = namespace
        if node_id is not None:
            self.node_id = node_id
        if import_microversion is not None:
            self.import_microversion = import_microversion
        if version is not None:
            self.version = version
        if path is not None:
            self.path = path

    @property
    def imported_external_document_id(self):
        """Gets the imported_external_document_id of this BTMImport.  # noqa: E501


        :return: The imported_external_document_id of this BTMImport.  # noqa: E501
        :rtype: str
        """
        return self._imported_external_document_id

    @imported_external_document_id.setter
    def imported_external_document_id(self, imported_external_document_id):
        """Sets the imported_external_document_id of this BTMImport.


        :param imported_external_document_id: The imported_external_document_id of this BTMImport.  # noqa: E501
        :type: str
        """

        self._imported_external_document_id = imported_external_document_id

    @property
    def element_import(self):
        """Gets the element_import of this BTMImport.  # noqa: E501


        :return: The element_import of this BTMImport.  # noqa: E501
        :rtype: bool
        """
        return self._element_import

    @element_import.setter
    def element_import(self, element_import):
        """Sets the element_import of this BTMImport.


        :param element_import: The element_import of this BTMImport.  # noqa: E501
        :type: bool
        """

        self._element_import = element_import

    @property
    def namespace(self):
        """Gets the namespace of this BTMImport.  # noqa: E501


        :return: The namespace of this BTMImport.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BTMImport.


        :param namespace: The namespace of this BTMImport.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def node_id(self):
        """Gets the node_id of this BTMImport.  # noqa: E501


        :return: The node_id of this BTMImport.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this BTMImport.


        :param node_id: The node_id of this BTMImport.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    @property
    def import_microversion(self):
        """Gets the import_microversion of this BTMImport.  # noqa: E501


        :return: The import_microversion of this BTMImport.  # noqa: E501
        :rtype: str
        """
        return self._import_microversion

    @import_microversion.setter
    def import_microversion(self, import_microversion):
        """Sets the import_microversion of this BTMImport.


        :param import_microversion: The import_microversion of this BTMImport.  # noqa: E501
        :type: str
        """

        self._import_microversion = import_microversion

    @property
    def version(self):
        """Gets the version of this BTMImport.  # noqa: E501


        :return: The version of this BTMImport.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BTMImport.


        :param version: The version of this BTMImport.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def path(self):
        """Gets the path of this BTMImport.  # noqa: E501


        :return: The path of this BTMImport.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this BTMImport.


        :param path: The path of this BTMImport.  # noqa: E501
        :type: str
        """

        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMImport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBillingPlanParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'application_id': 'str',
        'plan_id': 'str',
        'client_id': 'str',
        'amount_cents': 'int',
        'interval': 'str',
        'plan_type': 'int',
        'trial_period_days': 'int',
        'consumable_quantity': 'int',
        'hidden': 'bool',
        'description': 'str',
        'name': 'str',
        'group': 'str'
    }

    attribute_map = {
        'application_id': 'applicationId',
        'plan_id': 'planId',
        'client_id': 'clientId',
        'amount_cents': 'amountCents',
        'interval': 'interval',
        'plan_type': 'planType',
        'trial_period_days': 'trialPeriodDays',
        'consumable_quantity': 'consumableQuantity',
        'hidden': 'hidden',
        'description': 'description',
        'name': 'name',
        'group': 'group'
    }

    def __init__(self, application_id=None, plan_id=None, client_id=None, amount_cents=None, interval=None, plan_type=None, trial_period_days=None, consumable_quantity=None, hidden=None, description=None, name=None, group=None):  # noqa: E501
        """BTBillingPlanParams - a model defined in OpenAPI"""  # noqa: E501

        self._application_id = None
        self._plan_id = None
        self._client_id = None
        self._amount_cents = None
        self._interval = None
        self._plan_type = None
        self._trial_period_days = None
        self._consumable_quantity = None
        self._hidden = None
        self._description = None
        self._name = None
        self._group = None
        self.discriminator = None

        if application_id is not None:
            self.application_id = application_id
        if plan_id is not None:
            self.plan_id = plan_id
        if client_id is not None:
            self.client_id = client_id
        if amount_cents is not None:
            self.amount_cents = amount_cents
        if interval is not None:
            self.interval = interval
        if plan_type is not None:
            self.plan_type = plan_type
        if trial_period_days is not None:
            self.trial_period_days = trial_period_days
        if consumable_quantity is not None:
            self.consumable_quantity = consumable_quantity
        if hidden is not None:
            self.hidden = hidden
        if description is not None:
            self.description = description
        if name is not None:
            self.name = name
        if group is not None:
            self.group = group

    @property
    def application_id(self):
        """Gets the application_id of this BTBillingPlanParams.  # noqa: E501


        :return: The application_id of this BTBillingPlanParams.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this BTBillingPlanParams.


        :param application_id: The application_id of this BTBillingPlanParams.  # noqa: E501
        :type: str
        """

        self._application_id = application_id

    @property
    def plan_id(self):
        """Gets the plan_id of this BTBillingPlanParams.  # noqa: E501


        :return: The plan_id of this BTBillingPlanParams.  # noqa: E501
        :rtype: str
        """
        return self._plan_id

    @plan_id.setter
    def plan_id(self, plan_id):
        """Sets the plan_id of this BTBillingPlanParams.


        :param plan_id: The plan_id of this BTBillingPlanParams.  # noqa: E501
        :type: str
        """

        self._plan_id = plan_id

    @property
    def client_id(self):
        """Gets the client_id of this BTBillingPlanParams.  # noqa: E501


        :return: The client_id of this BTBillingPlanParams.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this BTBillingPlanParams.


        :param client_id: The client_id of this BTBillingPlanParams.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def amount_cents(self):
        """Gets the amount_cents of this BTBillingPlanParams.  # noqa: E501


        :return: The amount_cents of this BTBillingPlanParams.  # noqa: E501
        :rtype: int
        """
        return self._amount_cents

    @amount_cents.setter
    def amount_cents(self, amount_cents):
        """Sets the amount_cents of this BTBillingPlanParams.


        :param amount_cents: The amount_cents of this BTBillingPlanParams.  # noqa: E501
        :type: int
        """

        self._amount_cents = amount_cents

    @property
    def interval(self):
        """Gets the interval of this BTBillingPlanParams.  # noqa: E501


        :return: The interval of this BTBillingPlanParams.  # noqa: E501
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this BTBillingPlanParams.


        :param interval: The interval of this BTBillingPlanParams.  # noqa: E501
        :type: str
        """

        self._interval = interval

    @property
    def plan_type(self):
        """Gets the plan_type of this BTBillingPlanParams.  # noqa: E501


        :return: The plan_type of this BTBillingPlanParams.  # noqa: E501
        :rtype: int
        """
        return self._plan_type

    @plan_type.setter
    def plan_type(self, plan_type):
        """Sets the plan_type of this BTBillingPlanParams.


        :param plan_type: The plan_type of this BTBillingPlanParams.  # noqa: E501
        :type: int
        """

        self._plan_type = plan_type

    @property
    def trial_period_days(self):
        """Gets the trial_period_days of this BTBillingPlanParams.  # noqa: E501


        :return: The trial_period_days of this BTBillingPlanParams.  # noqa: E501
        :rtype: int
        """
        return self._trial_period_days

    @trial_period_days.setter
    def trial_period_days(self, trial_period_days):
        """Sets the trial_period_days of this BTBillingPlanParams.


        :param trial_period_days: The trial_period_days of this BTBillingPlanParams.  # noqa: E501
        :type: int
        """

        self._trial_period_days = trial_period_days

    @property
    def consumable_quantity(self):
        """Gets the consumable_quantity of this BTBillingPlanParams.  # noqa: E501


        :return: The consumable_quantity of this BTBillingPlanParams.  # noqa: E501
        :rtype: int
        """
        return self._consumable_quantity

    @consumable_quantity.setter
    def consumable_quantity(self, consumable_quantity):
        """Sets the consumable_quantity of this BTBillingPlanParams.


        :param consumable_quantity: The consumable_quantity of this BTBillingPlanParams.  # noqa: E501
        :type: int
        """

        self._consumable_quantity = consumable_quantity

    @property
    def hidden(self):
        """Gets the hidden of this BTBillingPlanParams.  # noqa: E501


        :return: The hidden of this BTBillingPlanParams.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this BTBillingPlanParams.


        :param hidden: The hidden of this BTBillingPlanParams.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    @property
    def description(self):
        """Gets the description of this BTBillingPlanParams.  # noqa: E501


        :return: The description of this BTBillingPlanParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTBillingPlanParams.


        :param description: The description of this BTBillingPlanParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """Gets the name of this BTBillingPlanParams.  # noqa: E501


        :return: The name of this BTBillingPlanParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTBillingPlanParams.


        :param name: The name of this BTBillingPlanParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def group(self):
        """Gets the group of this BTBillingPlanParams.  # noqa: E501


        :return: The group of this BTBillingPlanParams.  # noqa: E501
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this BTBillingPlanParams.


        :param group: The group of this BTBillingPlanParams.  # noqa: E501
        :type: str
        """

        self._group = group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBillingPlanParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTMIndividualQueryWithOccurrenceBase(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'path': 'list[str]',
        'deterministic_ids': 'list[str]',
        'deterministic_id_list': 'BTMIndividualQueryBase',
        'query': 'BTMIndividualQueryBase',
        'query_string': 'str',
        'import_microversion': 'str',
        'node_id': 'str'
    }

    attribute_map = {
        'path': 'path',
        'deterministic_ids': 'deterministicIds',
        'deterministic_id_list': 'deterministicIdList',
        'query': 'query',
        'query_string': 'queryString',
        'import_microversion': 'importMicroversion',
        'node_id': 'nodeId'
    }

    def __init__(self, path=None, deterministic_ids=None, deterministic_id_list=None, query=None, query_string=None, import_microversion=None, node_id=None):  # noqa: E501
        """BTMIndividualQueryWithOccurrenceBase - a model defined in OpenAPI"""  # noqa: E501

        self._path = None
        self._deterministic_ids = None
        self._deterministic_id_list = None
        self._query = None
        self._query_string = None
        self._import_microversion = None
        self._node_id = None
        self.discriminator = None

        if path is not None:
            self.path = path
        if deterministic_ids is not None:
            self.deterministic_ids = deterministic_ids
        if deterministic_id_list is not None:
            self.deterministic_id_list = deterministic_id_list
        if query is not None:
            self.query = query
        if query_string is not None:
            self.query_string = query_string
        if import_microversion is not None:
            self.import_microversion = import_microversion
        if node_id is not None:
            self.node_id = node_id

    @property
    def path(self):
        """Gets the path of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501


        :return: The path of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :rtype: list[str]
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this BTMIndividualQueryWithOccurrenceBase.


        :param path: The path of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :type: list[str]
        """

        self._path = path

    @property
    def deterministic_ids(self):
        """Gets the deterministic_ids of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501


        :return: The deterministic_ids of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :rtype: list[str]
        """
        return self._deterministic_ids

    @deterministic_ids.setter
    def deterministic_ids(self, deterministic_ids):
        """Sets the deterministic_ids of this BTMIndividualQueryWithOccurrenceBase.


        :param deterministic_ids: The deterministic_ids of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :type: list[str]
        """

        self._deterministic_ids = deterministic_ids

    @property
    def deterministic_id_list(self):
        """Gets the deterministic_id_list of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501


        :return: The deterministic_id_list of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :rtype: BTMIndividualQueryBase
        """
        return self._deterministic_id_list

    @deterministic_id_list.setter
    def deterministic_id_list(self, deterministic_id_list):
        """Sets the deterministic_id_list of this BTMIndividualQueryWithOccurrenceBase.


        :param deterministic_id_list: The deterministic_id_list of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :type: BTMIndividualQueryBase
        """

        self._deterministic_id_list = deterministic_id_list

    @property
    def query(self):
        """Gets the query of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501


        :return: The query of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :rtype: BTMIndividualQueryBase
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this BTMIndividualQueryWithOccurrenceBase.


        :param query: The query of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :type: BTMIndividualQueryBase
        """

        self._query = query

    @property
    def query_string(self):
        """Gets the query_string of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501


        :return: The query_string of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :rtype: str
        """
        return self._query_string

    @query_string.setter
    def query_string(self, query_string):
        """Sets the query_string of this BTMIndividualQueryWithOccurrenceBase.


        :param query_string: The query_string of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :type: str
        """

        self._query_string = query_string

    @property
    def import_microversion(self):
        """Gets the import_microversion of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501


        :return: The import_microversion of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :rtype: str
        """
        return self._import_microversion

    @import_microversion.setter
    def import_microversion(self, import_microversion):
        """Sets the import_microversion of this BTMIndividualQueryWithOccurrenceBase.


        :param import_microversion: The import_microversion of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :type: str
        """

        self._import_microversion = import_microversion

    @property
    def node_id(self):
        """Gets the node_id of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501


        :return: The node_id of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this BTMIndividualQueryWithOccurrenceBase.


        :param node_id: The node_id of this BTMIndividualQueryWithOccurrenceBase.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTMIndividualQueryWithOccurrenceBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



'''Given a model and a desired configuration, generate the link to get to the configuration.'''
from onshape_client.onshape_url import ConfiguredOnshapeElement
from onshape_client.units import u

# A configurable cube URL
url = "https://cad.onshape.com/documents/cca81d10f239db0db9481e6f/v/aaa25d18038e06f0b2964e2d/e/69c9eedda86512966b20bc90"
element = ConfiguredOnshapeElement(url)

# Desired configuration to apply to the cube
new_config_map = {'size': 10 * u.inch, 'edge_configuration': 'chamfered', 'show_cube': True}
element.update_current_configuration(new_config_map)
print("Link to model with the desired configuration applied: " + element.get_url_with_configuration())


# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTNotice(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'location_infos': 'list[BTLocationInfo]',
        'parameter_id': 'str',
        'type': 'str',
        'try_node': 'BTNodeReference',
        'level': 'str',
        'message': 'str',
        'stack_trace': 'list[BTLocationInfo]',
        'node_id': 'str'
    }

    attribute_map = {
        'location_infos': 'locationInfos',
        'parameter_id': 'parameterId',
        'type': 'type',
        'try_node': 'tryNode',
        'level': 'level',
        'message': 'message',
        'stack_trace': 'stackTrace',
        'node_id': 'nodeId'
    }

    def __init__(self, location_infos=None, parameter_id=None, type=None, try_node=None, level=None, message=None, stack_trace=None, node_id=None):  # noqa: E501
        """BTNotice - a model defined in OpenAPI"""  # noqa: E501

        self._location_infos = None
        self._parameter_id = None
        self._type = None
        self._try_node = None
        self._level = None
        self._message = None
        self._stack_trace = None
        self._node_id = None
        self.discriminator = None

        if location_infos is not None:
            self.location_infos = location_infos
        if parameter_id is not None:
            self.parameter_id = parameter_id
        if type is not None:
            self.type = type
        if try_node is not None:
            self.try_node = try_node
        if level is not None:
            self.level = level
        if message is not None:
            self.message = message
        if stack_trace is not None:
            self.stack_trace = stack_trace
        if node_id is not None:
            self.node_id = node_id

    @property
    def location_infos(self):
        """Gets the location_infos of this BTNotice.  # noqa: E501


        :return: The location_infos of this BTNotice.  # noqa: E501
        :rtype: list[BTLocationInfo]
        """
        return self._location_infos

    @location_infos.setter
    def location_infos(self, location_infos):
        """Sets the location_infos of this BTNotice.


        :param location_infos: The location_infos of this BTNotice.  # noqa: E501
        :type: list[BTLocationInfo]
        """

        self._location_infos = location_infos

    @property
    def parameter_id(self):
        """Gets the parameter_id of this BTNotice.  # noqa: E501


        :return: The parameter_id of this BTNotice.  # noqa: E501
        :rtype: str
        """
        return self._parameter_id

    @parameter_id.setter
    def parameter_id(self, parameter_id):
        """Sets the parameter_id of this BTNotice.


        :param parameter_id: The parameter_id of this BTNotice.  # noqa: E501
        :type: str
        """

        self._parameter_id = parameter_id

    @property
    def type(self):
        """Gets the type of this BTNotice.  # noqa: E501


        :return: The type of this BTNotice.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTNotice.


        :param type: The type of this BTNotice.  # noqa: E501
        :type: str
        """
        allowed_values = ["PARSE", "SEMANTIC", "EXECUTION", "GEOMETRY", "TEST", "OTHER", "UNKNOWN"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def try_node(self):
        """Gets the try_node of this BTNotice.  # noqa: E501


        :return: The try_node of this BTNotice.  # noqa: E501
        :rtype: BTNodeReference
        """
        return self._try_node

    @try_node.setter
    def try_node(self, try_node):
        """Sets the try_node of this BTNotice.


        :param try_node: The try_node of this BTNotice.  # noqa: E501
        :type: BTNodeReference
        """

        self._try_node = try_node

    @property
    def level(self):
        """Gets the level of this BTNotice.  # noqa: E501


        :return: The level of this BTNotice.  # noqa: E501
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this BTNotice.


        :param level: The level of this BTNotice.  # noqa: E501
        :type: str
        """
        allowed_values = ["INTERNAL", "ERROR", "WARNING", "INFO", "UNKNOWN"]  # noqa: E501
        if level not in allowed_values:
            raise ValueError(
                "Invalid value for `level` ({0}), must be one of {1}"  # noqa: E501
                .format(level, allowed_values)
            )

        self._level = level

    @property
    def message(self):
        """Gets the message of this BTNotice.  # noqa: E501


        :return: The message of this BTNotice.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this BTNotice.


        :param message: The message of this BTNotice.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def stack_trace(self):
        """Gets the stack_trace of this BTNotice.  # noqa: E501


        :return: The stack_trace of this BTNotice.  # noqa: E501
        :rtype: list[BTLocationInfo]
        """
        return self._stack_trace

    @stack_trace.setter
    def stack_trace(self, stack_trace):
        """Sets the stack_trace of this BTNotice.


        :param stack_trace: The stack_trace of this BTNotice.  # noqa: E501
        :type: list[BTLocationInfo]
        """

        self._stack_trace = stack_trace

    @property
    def node_id(self):
        """Gets the node_id of this BTNotice.  # noqa: E501


        :return: The node_id of this BTNotice.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this BTNotice.


        :param node_id: The node_id of this BTNotice.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTNotice):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from pathlib import Path
from ruamel.yaml import YAML
import os
from requests_oauthlib import OAuth2Session
from .oauth.local_server import start_server
from enum import Enum
import webbrowser
from oauthlib.oauth2 import UnauthorizedClientError, UnsupportedGrantTypeError, MissingTokenError
from onshape_client.oas import api
from onshape_client.oas import ApiClient
from onshape_client.oas.configuration import Configuration



class Client:
    """
    Initialize an Onshape client.

    The default is to pull the configuration from a file located in the user's home
    directory. However, configs can also be passed directly as a dictionary.

    Keys can be obtained from https://dev-portal.onshape.com.

    Parameters
    ----------
    conf_file : :obj:`str`, optional
        The path to the location of an onshape_client_config YAML file, where multiple stacks may be declared.
    configuration : :obj:`dict`, optional
        This overrides the conf_file parameter by supplying a dictionary that looks like the following:
        {
            "base_url": "https://cad.onshape.com",
            "access_key": "YOUR_ACCESS_KEY_HERE",
            "secret_key": "YOUR_SECRET_KEY_HERE"
        }
    stack_key : :obj:`str`, optional
        The key of the name for the particular stack to be used. Only applicable when reading configuration from the
        conf_file.
    """
    __instance = None
    __singleton = True

    @classmethod
    def set_singleton(cls, is_singleton):
        cls.__singleton = is_singleton

    @staticmethod
    def get_client(create_if_needed=True):
        """ get an instance of the client class singleton. """
        if not Client.__singleton:
            raise ValueError('The Singleton option is turned off')
        client = Client.__instance
        if not client:
            if create_if_needed:
                client = Client()
            else:
                raise Exception("Please manually instantiate the client.")
        return client

    @staticmethod
    def clear_client():
        """ delete the singleton instance of the client. """
        if not Client.__singleton:
            raise ValueError('The Singleton option is turned off')
        Client.__instance = None

    @staticmethod
    def get_configuration_from_keys_file(keys_file, stack_key):
        try:
            yaml = YAML()
            configurations_file = yaml.load(Path(keys_file))
            final_configuration = configurations_file[stack_key if stack_key else configurations_file['default_stack']]
        except KeyError as e:
            raise KeyError(
                "Your creds file is not constructed as expected. The key: {} was expected and now found.".format(e))
        return final_configuration

    def __init__(self, keys_file="~/.onshape_client_config.yaml", configuration=None, stack_key=None, open_authorize_grant_callback=None):
        """

        :param keys_file:
        :param configuration:
        :param stack_key:
        :param open_authorize_grant_callback: This will get called when the application needs to show the user the grant
            authorization page. It gets passed the URL to go to. Once the grant is authorized, the application needs to
            call client.set_grant_authorization_url_response(redirected_url) with whatever url the user got directed to
            (that includes the authorization code!)
        """
        if Client.__singleton and Client.__instance != None:
            raise Exception("This class is a singleton! Please use 'get_client' for all subsequent calls.")
        if configuration:
            final_configuration = configuration
        elif keys_file:
            keys_file = os.path.expanduser(keys_file)
            final_configuration = self.get_configuration_from_keys_file(keys_file, stack_key)
        else:
            raise EnvironmentError("API keys were not properly set.")

        self._set_configuration(final_configuration)
        self._create_apis()
        self.open_authorize_grant_callback = open_authorize_grant_callback

        if self.get_authentication_method() == "oauth":
            self._set_oauth_session()

        Client.__instance = self

    def set_grant_authorization_url_response(self, authorization_url_response):
        """ This is the redirected-to url, for example: https:localhost/oauth_redirect?code=XraRXPYGSWfZmBvUIiNHvSlZ&state=kgZQJbVp731CgNxAeKJN7TIoOlo5bz"""
        self.fetch_access_token(authorization_url_response)

    def get_authentication_method(self):
        # Prefer OAUTH if specified, otherwise try for apikeys
        if self.client_secret and self.client_id:
            return "oauth"
        elif self.configuration.api_key['SECRET_KEY'] and self.configuration.api_key['ACCESS_KEY']:
            return "api_keys"
        else:
            return None

    def get_authorization_url(self):
        url, state = self.oauth.authorization_url(self.authorization_uri)
        return url

    def do_oauth_flow(self):
        """Do the oauth flow to set the access token"""
        try:
            self._refresh_access_token()
        except (UnauthorizedClientError, UnsupportedGrantTypeError, MissingTokenError) as e:
            authorization_method = OAuthAuthorizationMethods(self.oauth_authorization_method)
            oauth_type = OAuthAuthorizationMethods(self.oauth_authorization_method)
            if oauth_type == OAuthAuthorizationMethods.MANUAL_FLOW:
                raise OAuthNotAuthorizedException("You need to have the user authorize the grant.")
            elif authorization_method == OAuthAuthorizationMethods.LOCALHOST_SERVER:
                start_server(self.fetch_access_token, self.open_authorize_grant)
            elif authorization_method == OAuthAuthorizationMethods.PYTHON_CALLBACK:
                self.open_authorize_grant()

    def open_authorize_grant(self):
        done = self.fetch_access_token
        callback = self.open_authorize_grant_callback
        oauth_type = OAuthAuthorizationMethods(self.oauth_authorization_method)
        url = self.get_authorization_url()
        defaults_supported = [OAuthAuthorizationMethods.LOCALHOST_SERVER]
        if not callback and oauth_type not in defaults_supported:
            raise NotImplementedError("To use OAuth, you need to pass in a callback to the client constructor with open_authorize_grant_callback=")
        elif callback:
            try:
                if callback and not callable(callback):
                    # Attempt to evaluate the function definition
                    callback = eval(callback)
                callback(url, done)
            except:
                raise AttributeError("The open_authorize_grant_callback function did not work.")
        else:
            self.default_callback(url)

    def default_callback(self, url):
        authorization_method = OAuthAuthorizationMethods(self.oauth_authorization_method)
        if authorization_method == OAuthAuthorizationMethods.LOCALHOST_SERVER:
            webbrowser.open(url)

    def _set_configuration(self, configuration_dictionary):
        configuration = Configuration()

        configuration.verify_ssl = False
        configuration.api_key['SECRET_KEY'] = self._get_if_present(configuration_dictionary, 'secret_key')
        configuration.api_key['ACCESS_KEY'] = self._get_if_present(configuration_dictionary, 'access_key')

        self.client_id = self._get_if_present(configuration_dictionary, 'client_id')
        self.client_secret = self._get_if_present(configuration_dictionary, 'client_secret')
        configuration.access_token = self._get_if_present(configuration_dictionary, 'access_token')
        self.refresh_token = self._get_if_present(configuration_dictionary, 'refresh_token')
        self.scope = self._get_if_present(configuration_dictionary, 'scope')
        self.redirect_uri = self._get_if_present(configuration_dictionary, 'redirect_uri')
        self.token_uri = self._get_if_present(configuration_dictionary, 'token_uri')
        self.authorization_uri = self._get_if_present(configuration_dictionary, 'authorization_uri')
        self.oauth_authorization_method = self._get_if_present(configuration_dictionary, 'oauth_authorization_method')

        configuration.host = self._get_if_present(configuration_dictionary, 'base_url')
        self.configuration = configuration
        return

    def _set_oauth_session(self):
        self.oauth = OAuth2Session(self.client_id, redirect_uri=self.redirect_uri,
                                           scope=self.scope)
        return

    def _refresh_access_token(self):
        # So that the oauth library doesn't complain about scope changing
        os.environ["OAUTHLIB_RELAX_TOKEN_SCOPE"] = "True"

        token_response = self.oauth.refresh_token(
            self.token_uri, refresh_token=self.refresh_token, client_id=self.client_id, client_secret=self.client_secret)
        self._set_oauth_creds_from_token_response(token_response)
        return

    def fetch_access_token(self, **kwargs):
        """
        :param authorization_response: The response containing the authorization code.
        :return: The access token and the refresh token. These should be stored by the caller to facilitate future
        client initialization.
        """
        try:
            token_response = self.oauth.fetch_token(
            self.token_uri,
            client_secret=self.client_secret,
            **kwargs)
            self._set_oauth_creds_from_token_response(token_response)
            return token_response
        except Warning:
            # This is probably a scope warning.
            pass


    def _set_oauth_creds_from_token_response(self, token_response):
        self.configuration.access_token = token_response["access_token"]
        self.refresh_token = token_response["refresh_token"]
        return


    @staticmethod
    def _get_if_present(dictionary, key):
        return dictionary[key] if key in dictionary else ""

    def _create_apis(self):
        api_client = ApiClient(configuration=self.configuration)
        self.accounts_api = api.AccountsApi(api_client)
        self.app_elements_api = api.AppElementsApi(api_client)
        self.assemblies_api = api.AssembliesApi(api_client)
        self.blob_elements_api = api.BlobElementsApi(api_client)
        self.drawings_api = api.DrawingsApi(api_client)
        self.documents_api = api.DocumentsApi(api_client)
        self.elements_api = api.ElementsApi(api_client)
        self.feature_studios_api = api.FeatureStudiosApi(api_client)
        self.metadata_api = api.MetadataApi(api_client)
        self.parts_api = api.PartsApi(api_client)
        self.part_studios_api = api.PartStudiosApi(api_client)
        self.translation_api = api.TranslationsApi(api_client)

class OAuthAuthorizationMethods(Enum):

    # This is fully implemented, and meant for locally hosted applications (desktop apps)
    LOCALHOST_SERVER="localhost_server"

    # This is for when the open_authorize_grant_callback is set. It yields control to this client
    # by specifying a function that should be called to authorize the grant, and passes in a
    # function to that callback that needs to be called when the grant has been authorized with
    # the result.
    PYTHON_CALLBACK="python_callback"

    # This flow will communicate that the client needs the authorization flow with an OAuthNotAuthorizedException
    # after failing to refresh the token. Once the client throws the error, the application should
    # call client.get_authorization_url() and present the resulting url to the user, and subsequently
    # call client.fetch_access_token(resulting_url_with_authorization_code) to complete the flow.
    # Note that for the best user experience, the client should store the refresh_token in persistent
    # storage so the user only has to go through the grant authorization step once.
    MANUAL_FLOW = "manual_flow"

# Exception that should be caught signaling that the user should go through the grant authorization flow.
class OAuthNotAuthorizedException(Exception):
    def __init__(self, *args, **kwargs):
        super(OAuthNotAuthorizedException, self).__init__(args, kwargs)




# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.104
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTExportModelEdgeGeometry(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'start_point': 'BTVector3d',
        'end_point': 'BTVector3d',
        'mid_point': 'BTVector3d',
        'quarter_point': 'BTVector3d',
        'start_vector': 'BTVector3d',
        'end_vector': 'BTVector3d',
        'length': 'float'
    }

    attribute_map = {
        'start_point': 'startPoint',
        'end_point': 'endPoint',
        'mid_point': 'midPoint',
        'quarter_point': 'quarterPoint',
        'start_vector': 'startVector',
        'end_vector': 'endVector',
        'length': 'length'
    }

    def __init__(self, start_point=None, end_point=None, mid_point=None, quarter_point=None, start_vector=None, end_vector=None, length=None):  # noqa: E501
        """BTExportModelEdgeGeometry - a model defined in OpenAPI"""  # noqa: E501

        self._start_point = None
        self._end_point = None
        self._mid_point = None
        self._quarter_point = None
        self._start_vector = None
        self._end_vector = None
        self._length = None
        self.discriminator = None

        if start_point is not None:
            self.start_point = start_point
        if end_point is not None:
            self.end_point = end_point
        if mid_point is not None:
            self.mid_point = mid_point
        if quarter_point is not None:
            self.quarter_point = quarter_point
        if start_vector is not None:
            self.start_vector = start_vector
        if end_vector is not None:
            self.end_vector = end_vector
        if length is not None:
            self.length = length

    @property
    def start_point(self):
        """Gets the start_point of this BTExportModelEdgeGeometry.  # noqa: E501


        :return: The start_point of this BTExportModelEdgeGeometry.  # noqa: E501
        :rtype: BTVector3d
        """
        return self._start_point

    @start_point.setter
    def start_point(self, start_point):
        """Sets the start_point of this BTExportModelEdgeGeometry.


        :param start_point: The start_point of this BTExportModelEdgeGeometry.  # noqa: E501
        :type: BTVector3d
        """

        self._start_point = start_point

    @property
    def end_point(self):
        """Gets the end_point of this BTExportModelEdgeGeometry.  # noqa: E501


        :return: The end_point of this BTExportModelEdgeGeometry.  # noqa: E501
        :rtype: BTVector3d
        """
        return self._end_point

    @end_point.setter
    def end_point(self, end_point):
        """Sets the end_point of this BTExportModelEdgeGeometry.


        :param end_point: The end_point of this BTExportModelEdgeGeometry.  # noqa: E501
        :type: BTVector3d
        """

        self._end_point = end_point

    @property
    def mid_point(self):
        """Gets the mid_point of this BTExportModelEdgeGeometry.  # noqa: E501


        :return: The mid_point of this BTExportModelEdgeGeometry.  # noqa: E501
        :rtype: BTVector3d
        """
        return self._mid_point

    @mid_point.setter
    def mid_point(self, mid_point):
        """Sets the mid_point of this BTExportModelEdgeGeometry.


        :param mid_point: The mid_point of this BTExportModelEdgeGeometry.  # noqa: E501
        :type: BTVector3d
        """

        self._mid_point = mid_point

    @property
    def quarter_point(self):
        """Gets the quarter_point of this BTExportModelEdgeGeometry.  # noqa: E501


        :return: The quarter_point of this BTExportModelEdgeGeometry.  # noqa: E501
        :rtype: BTVector3d
        """
        return self._quarter_point

    @quarter_point.setter
    def quarter_point(self, quarter_point):
        """Sets the quarter_point of this BTExportModelEdgeGeometry.


        :param quarter_point: The quarter_point of this BTExportModelEdgeGeometry.  # noqa: E501
        :type: BTVector3d
        """

        self._quarter_point = quarter_point

    @property
    def start_vector(self):
        """Gets the start_vector of this BTExportModelEdgeGeometry.  # noqa: E501


        :return: The start_vector of this BTExportModelEdgeGeometry.  # noqa: E501
        :rtype: BTVector3d
        """
        return self._start_vector

    @start_vector.setter
    def start_vector(self, start_vector):
        """Sets the start_vector of this BTExportModelEdgeGeometry.


        :param start_vector: The start_vector of this BTExportModelEdgeGeometry.  # noqa: E501
        :type: BTVector3d
        """

        self._start_vector = start_vector

    @property
    def end_vector(self):
        """Gets the end_vector of this BTExportModelEdgeGeometry.  # noqa: E501


        :return: The end_vector of this BTExportModelEdgeGeometry.  # noqa: E501
        :rtype: BTVector3d
        """
        return self._end_vector

    @end_vector.setter
    def end_vector(self, end_vector):
        """Sets the end_vector of this BTExportModelEdgeGeometry.


        :param end_vector: The end_vector of this BTExportModelEdgeGeometry.  # noqa: E501
        :type: BTVector3d
        """

        self._end_vector = end_vector

    @property
    def length(self):
        """Gets the length of this BTExportModelEdgeGeometry.  # noqa: E501


        :return: The length of this BTExportModelEdgeGeometry.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this BTExportModelEdgeGeometry.


        :param length: The length of this BTExportModelEdgeGeometry.  # noqa: E501
        :type: float
        """

        self._length = length

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTExportModelEdgeGeometry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
